@@ -123,7 +123,7 @@ QString Ebook_CHM_Encoding::guessByLCID(unsigned short lcid)
     for (const EbookChmTextEncodingEntry *t = text_encoding_table; t->qtcodec; ++t) {
         for (const short *lcids = t->lcids; *lcids; lcids++) {
             if (*lcids == lcid) {
-                return t->qtcodec;
+                return QString::fromLatin1(t->qtcodec);
             }
         }
     }
